var app = require('http').createServer(handler),
    io = require('socket.io').listen(app),
    fs = require('fs'),
    net = require('net'),
    url = require('url'),
    canvasdata = require('./canvasdata'),
    tlframes = [],
    flashSock;

for(var i = 0, len = 6; i < len; i++){
    tlframes[i] = new canvasdata.TLFrame();
}

var responseFile = function(path, res){
    fs.readFile(__dirname + path, function (err, data) {
        if (err) {
            res.writeHead(500);
            return res.end('Error loading index.html');
        }

        res.writeHead(200);
        res.end(data);
    });
};

function handler(req, res) {
    var path = url.parse(req.url);
    if(path.href === '/'){
        responseFile('/index.html', res);
    }else if(path.href === '/canvasdata.js'){
        responseFile('/canvasdata.js', res);
    }else if(path.href === '/ui_image.png'){
        responseFile('/ui_image.png', res);
    }else if(path.href === '/canvas.swf.html'){
        responseFile('/../flash/flash/canvas.swf.html', res);
    }else{
        res.writeHead(404);
        res.end('not found');
    }
};

app.listen(4000);

io.set('log level', 2);

io.sockets.on('connection', function (socket) {
    //clone
    var frame,
        stroke,
        flashJSON;
    socket.emit('clone', { type:'start' });
    for(var i = 0, len = tlframes.length; i < len; i += 1){
        frame = tlframes[i];
        for(var j = 0, len2 = frame.getStrokeLength(); j < len2; j += 1){
            stroke = frame.getStroke(j);
            socket.emit('clone', {
                type:'add',
                frame:i,
                stroke:j,
                width:stroke.width,
                color:stroke.color,
                points:stroke.points        
            });
        }
    }
    socket.emit('clone', { type:'end' });

    //touch

    socket.on('touch', function(data){
        if(data.type === 'start'){
            frame = tlframes[data.frame];
            data.stroke = frame.getStrokeLength();
            stroke = new canvasdata.Stroke(data.width, data.color);
            stroke.points.push(data.x, data.y);
            frame.addStroke(stroke);
            io.sockets.emit('touch', data);
            
        }else if(data.type === 'move'){
            frame = tlframes[data.frame];
            stroke = frame.getStroke(data.stroke);
            stroke.points.push(data.x, data.y);
            io.sockets.emit('touch', data);

        }else if(data.type === 'end'){
            if(flashSock){
                frame = tlframes[data.frame];
                stroke = frame.getStroke(data.stroke);
                flashJSON = JSON.stringify({
                    "frame":data.frame,
                    "stroke":stroke
                });
                flashSock.write(flashJSON); 
                //JSON.parse(text);
            }
        }
    });
    socket.on('publish', function(data){
        flashJSON = JSON.stringify({"type":"publish"});
        flashSock.write(flashJSON);
    });
});


var sockServer = net.createServer(function(socket){
    console.log('client connected');
    flashSock = socket;

    socket.on('end', function(){
        console.log('client disconnected');
    });
    socket.on('data', function(buf){
        var msg = buf.toString();
        if(msg.indexOf('swiffy complete') !== -1){
            io.sockets.emit('location', {href:'canvas.swf.html'});
            //console.log('complete');
        }
    });
});

sockServer.listen(3000, function(){
    console.log('server listen');
});
